@@ -25,8 +25,8 @@
 
 #include <tqtimer.h>
 
-#include <kglobal.h>
-#include <kconfig.h>
+#include <tdeglobal.h>
+#include <tdeconfig.h>
 #include <kstaticdeleter.h>
 #include <kdebug.h>
 
@@ -98,7 +98,7 @@ Storage::slotConnectionAdded(Connection* con)
 {
 	// connection added, save it
 	saveConnection(con);
-	KGlobal::config()->sync();
+	TDEGlobal::config()->sync();
 }
 
 void
@@ -106,7 +106,7 @@ Storage::slotConnectionRemoved(Connection* con)
 {
 	// find the appropriate connection and delete it from the storage
 	deleteConnection(con);
-	KGlobal::config()->sync();
+	TDEGlobal::config()->sync();
 }
 
 Connection*
@@ -133,7 +133,7 @@ Storage::restoreConnections()
 	kdDebug() << k_funcinfo << endl;
 	// let's read all connections from the config-file and add them to the connection-store
 	ConnectionStore* store = ConnectionStore::getInstance();
-	TQStringList groups = KGlobal::config()->groupList();
+	TQStringList groups = TDEGlobal::config()->groupList();
 	const TQStringList::Iterator end = groups.end();
 	for ( TQStringList::Iterator it = groups.begin(); it != end; ++it )
 	{
@@ -158,7 +158,7 @@ Storage::restoreConnection(const TQString& grpname)
 	kdDebug() << k_funcinfo << " " << grpname << endl;
 
 	// we have a connection to restore
-	KConfigGroup grp( KGlobal::config(), grpname);
+	TDEConfigGroup grp( TDEGlobal::config(), grpname);
 	TQString id = grp.readEntry("Id");
 	TQString cType = grp.readEntry("Type");
 
@@ -217,8 +217,8 @@ Storage::restoreSetting(Connection* conn, const TQString& setting_grp_name)
 	kdDebug() << k_funcinfo << " " << setting_grp_name << endl;
 	kdDebug() << "restore setting: " << setting_grp_name.ascii() << endl;
 
-	KConfigGroup setting_grp(KGlobal::config(), setting_grp_name);
-	TQMap<TQString, TQString> config_map = KGlobal::config()->entryMap(setting_grp_name);
+	TDEConfigGroup setting_grp(TDEGlobal::config(), setting_grp_name);
+	TQMap<TQString, TQString> config_map = TDEGlobal::config()->entryMap(setting_grp_name);
 	TQString type = setting_grp.readEntry("Type");
 		
 	// get the appropriate setting from the connection
@@ -229,7 +229,7 @@ Storage::restoreSetting(Connection* conn, const TQString& setting_grp_name)
 		return false;
 	}
 
-	// read the SettingsMap from kconfig
+	// read the SettingsMap from tdeconfig
 	SettingsMap map;
 	for(TQMap<TQString, TQString>::ConstIterator it = config_map.begin(); it != config_map.end(); ++it)
 	{
@@ -257,8 +257,8 @@ Storage::restoreSecrets(Connection* conn, const TQString& secrets_grp_name)
 	kdDebug() << k_funcinfo << " " << secrets_grp_name << endl;
 	kdDebug() << "restore secret: " << secrets_grp_name.ascii() << endl;
 
-	KConfigGroup secrets_grp(KGlobal::config(), secrets_grp_name);
-	TQMap<TQString, TQString> config_map = KGlobal::config()->entryMap(secrets_grp_name);
+	TDEConfigGroup secrets_grp(TDEGlobal::config(), secrets_grp_name);
+	TQMap<TQString, TQString> config_map = TDEGlobal::config()->entryMap(secrets_grp_name);
 	TQString type = secrets_grp.readEntry("Type");
 		
 	// get the appropriate setting from the connection
@@ -269,7 +269,7 @@ Storage::restoreSecrets(Connection* conn, const TQString& secrets_grp_name)
 		return false;
 	}
 
-	// read the SettingsMap from kconfig
+	// read the SettingsMap from tdeconfig
 	SettingsMap map;
 	for(TQMap<TQString, TQString>::ConstIterator it = config_map.begin(); it != config_map.end(); ++it)
 	{
@@ -297,8 +297,8 @@ Storage::restoreVPNSecrets(Connection* conn, const TQString& secrets_grp_name)
 	kdDebug() << k_funcinfo << " " << secrets_grp_name << endl;
 	kdDebug() << "restore secret: " << secrets_grp_name.ascii() << endl;
 
-	KConfigGroup secrets_grp(KGlobal::config(), secrets_grp_name);
-	TQMap<TQString, TQString> config_map = KGlobal::config()->entryMap(secrets_grp_name);
+	TDEConfigGroup secrets_grp(TDEGlobal::config(), secrets_grp_name);
+	TQMap<TQString, TQString> config_map = TDEGlobal::config()->entryMap(secrets_grp_name);
 	TQString type = secrets_grp.readEntry("Type");
 		
 	// get the appropriate setting from the connection
@@ -309,7 +309,7 @@ Storage::restoreVPNSecrets(Connection* conn, const TQString& secrets_grp_name)
 		return false;
 	}
 
-	// read the SettingsMap from kconfig
+	// read the SettingsMap from tdeconfig
 	SettingsMap map;
 	for(TQMap<TQString, TQString>::ConstIterator it = config_map.begin(); it != config_map.end(); ++it)
 	{
@@ -346,13 +346,13 @@ Storage::saveConnections()
 		// save this connection
 		saveConnection(*it);
 	}
-	KGlobal::config()->sync();
+	TDEGlobal::config()->sync();
 }
 
 bool
 Storage::saveConnection(Connection* conn)
 {
-	KConfig* config = KGlobal::config();
+	TDEConfig* config = TDEGlobal::config();
 	TQString id = conn->getID();
 	TQString cType = conn->getType();
 
@@ -364,7 +364,7 @@ Storage::saveConnection(Connection* conn)
 		return false;
 
 	// let's get the config group for this connection
-	KConfigGroup grp(config, TQString("Connection_%1").arg(id));
+	TDEConfigGroup grp(config, TQString("Connection_%1").arg(id));
 	TQStringList settings_grps;
 	TQStringList secrets_grps;
 
@@ -416,7 +416,7 @@ Storage::saveConnectionSettings(Connection* conn, TQStringList& settings_grps, T
 bool
 Storage::saveConnectionSetting(Connection* conn, ConnectionSetting* setting, TQString& setting_grp)
 {
-	KConfig* config = KGlobal::config();
+	TDEConfig* config = TDEGlobal::config();
 	TQString id = conn->getID();
 	TQString type = setting->getType();
 
@@ -428,7 +428,7 @@ Storage::saveConnectionSetting(Connection* conn, ConnectionSetting* setting, TQS
 
 	// get a group for this setting
 	setting_grp = TQString("ConnectionSetting_%1_%2").arg(id).arg(type);
-	KConfigGroup grp(config, setting_grp);
+	TDEConfigGroup grp(config, setting_grp);
 
 	// write the type
 	grp.writeEntry("Type", type);
@@ -446,7 +446,7 @@ Storage::saveConnectionSetting(Connection* conn, ConnectionSetting* setting, TQS
 bool
 Storage::saveConnectionSecrets(Connection* conn, ConnectionSetting* setting, TQString& setting_grp)
 {
-	KConfig* config = KGlobal::config();
+	TDEConfig* config = TDEGlobal::config();
 	TQString id = conn->getID();
 	TQString type = setting->getType();
 	bool storage_requested;
@@ -475,7 +475,7 @@ Storage::saveConnectionSecrets(Connection* conn, ConnectionSetting* setting, TQS
 
 	// get a group for this setting
 	setting_grp = TQString("ConnectionSecrets_%1_%2").arg(id).arg(type);
-	KConfigGroup grp(config, setting_grp);
+	TDEConfigGroup grp(config, setting_grp);
 
 	// write the type
 	grp.writeEntry("Type", type);
@@ -529,7 +529,7 @@ Storage::hasSecretsStored(Connection* connection, ConnectionSetting* setting)
 	// get a group for this setting
 	TQString setting_grp_name = TQString("ConnectionSecrets_%1_%2").arg(id).arg(type);
 
-	TQMap<TQString, TQString> config_map = KGlobal::config()->entryMap(setting_grp_name);
+	TQMap<TQString, TQString> config_map = TDEGlobal::config()->entryMap(setting_grp_name);
 
 	return !(config_map.isEmpty());
 }
@@ -593,7 +593,7 @@ Storage::restoreVPNSecrets(Connection* connection, ConnectionSetting* setting)
 bool
 Storage::deleteConnection(Connection* conn)
 {
-	KConfig* config = KGlobal::config();
+	TDEConfig* config = TDEGlobal::config();
 	TQString id = conn->getID();
 	TQString cType = conn->getType();
 
@@ -605,7 +605,7 @@ Storage::deleteConnection(Connection* conn)
 		return false;
 
 	// let's get the config group for this connection
-	KConfigGroup grp(config, TQString("Connection_%1").arg(id));
+	TDEConfigGroup grp(config, TQString("Connection_%1").arg(id));
 
 
 	// delete all associated settings
@@ -613,7 +613,7 @@ Storage::deleteConnection(Connection* conn)
 
 	for (TQStringList::ConstIterator it = settings.begin(); it != settings.end(); ++it)
 	{
-		KConfigGroup setting(config, *it);
+		TDEConfigGroup setting(config, *it);
 		setting.deleteGroup();
 	}
 
@@ -622,7 +622,7 @@ Storage::deleteConnection(Connection* conn)
 
 	for (TQStringList::ConstIterator it = secrets.begin(); it != secrets.end(); ++it)
 	{
-		KConfigGroup setting(config, *it);
+		TDEConfigGroup setting(config, *it);
 		setting.deleteGroup();
 	}
 
